==> 0.1.16.tar.gz: lib/dilithium.dart <==
/*
           ___ ___ __  __    _
      ____/ (_) (_) /_/ /_  (_)_  ______ ___
     / __  / / / / __/ __ \/ / / / / __ `__ \
    / /_/ / / / / /_/ / / / / /_/ / / / / / /
    \__,_/_/_/_/\__/_/ /_/_/\__,_/_/ /_/ /_/


Copyright (c) 2014 Bruce Davidson <darkoverlordofdata@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
'Software'), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

library dilithium;

import 'dart:html';
import 'dart:js';
import 'dart:async' as async;

import 'package:yaml/yaml.dart';
import 'package:play_phaser/phaser.dart' as Phaser;

part 'src/Dilithium.dart';
part 'src/Li2Assets.dart';
part 'src/Li2Boot.dart';
part 'src/Li2Button.dart';
part 'src/Li2Config.dart';
part 'src/Li2State.dart';
part 'src/Li2Template.dart';

==> 0.2.4.tar.gz: lib/dilithium.dart <==
/*
           ___ ___ __  __    _
      ____/ (_) (_) /_/ /_  (_)_  ______ ___
     / __  / / / / __/ __ \/ / / / / __ `__ \
    / /_/ / / / / /_/ / / / / /_/ / / / / / /
    \__,_/_/_/_/\__/_/ /_/_/\__,_/_/ /_/ /_/


Copyright (c) 2014 Bruce Davidson <darkoverlordofdata@gmail.com>

Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files (the
'Software'), to deal in the Software without restriction, including
without limitation the rights to use, copy, modify, merge, publish,
distribute, sublicense, and/or sell copies of the Software, and to
permit persons to whom the Software is furnished to do so, subject to
the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED 'AS IS', WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
*/

library dilithium;

import 'dart:html';
import 'dart:js';
import 'dart:async' as async;
import 'dart:math' as math;

import 'package:yaml/yaml.dart';
import 'package:play_phaser/phaser.dart' as Phaser;

part 'src/dilithium.dart';
part 'src/li2_assets.dart';
part 'src/li2_boot.dart';
part 'src/li2_button.dart';
part 'src/li2_config.dart';
part 'src/li2_state.dart';
part 'src/li2_template.dart';
